# Change Log 

* Version 0.0.5 (2021-07-20)
	* Intialize
	* Start from 0.0.5 as previous versions are all failed
	* Remove __os__, __re__, __string__ from 'install_requires', as they are built-in packages. Issue raise up if list those packages. 

* Version 0.0.6 (2021-07-20)
	* Merge scripts into __init__.py. Script can not load function from another. 
